@@ -66,9 +66,14 @@ class consistenthashing(object):
     def getNode(self, key):
         '''Give a key, return which server this key belongs to
         '''
-        hashValue = self._getHashValue(key)
-        l = [x for x in self.nodes.keys() if x - hashValue >= 0]
-        return self.nodes[min(l)]
+        if self.nodeList:
+            hashValue = self._getHashValue(key)
+            if hashValue > max(self.nodes.keys()):
+                return self.nodes[min(self.nodes.keys())]
+            l = [x for x in self.nodes.keys() if x - hashValue >= 0]
+            return self.nodes[min(l)]
+        print 'Node list is empty, please use addNode() method to add node'
+        return None
 
     def _getHashValue(self, key):
         hashFunction = hashlib.md5()
